@@ -58,7 +58,11 @@ print.metadata.dicom <- function (x, descriptions = FALSE, ...)
 {
     tags <- x$getAvailableTags()
     if (descriptions && !exists("dictionary"))
-        data("dictionary", envir=environment(NULL))
+    {
+        # First set to NULL to keep package checker happy
+        dictionary <- NULL
+        data("dictionary", package="tractor.base", envir=environment(NULL))
+    }
     
     if (length(tags) > 0)
     {
@@ -331,7 +335,8 @@ newMriImageFromDicomDirectory <- function (dicomDir, readDiffusionParams = FALSE
     files <- files[!file.info(files)$isdir]
     nFiles <- length(files)
     
-    data("dictionary", envir=environment(NULL))
+    dictionary <- NULL
+    data("dictionary", package="tractor.base", envir=environment(NULL))
 
     output(OL$Info, "Reading image information from ", nFiles, " files")
     seriesNumbers <- numeric(0)
@@ -567,7 +572,7 @@ newDicomMetadataFromFile <- function (fileName, checkFormat = TRUE, dictionary =
     if (checkFormat)
     {
         seek(connection, where=128)
-        str <- rawToCharQuiet(readBin(connection, "raw", n=4))
+        str <- rawToChar(stripNul(readBin(connection, "raw", n=4)))
         if (str == "DICM")
         {
             isDicomFile <- TRUE
@@ -587,7 +592,7 @@ newDicomMetadataFromFile <- function (fileName, checkFormat = TRUE, dictionary =
         endian <- setdiff(c("big","little"), .Platform$endian)
     
     seek(connection, where=2, origin="current")
-    type <- rawToCharQuiet(readBin(connection, "raw", n=2))
+    type <- rawToChar(stripNul(readBin(connection, "raw", n=2)))
     if (type == "UL")
         explicitTypes <- TRUE
     else
@@ -628,7 +633,7 @@ newDicomMetadataFromFile <- function (fileName, checkFormat = TRUE, dictionary =
             }
             else if (explicitTypes)
             {
-                type <- rawToCharQuiet(readBin(connection, "raw", n=2))
+                type <- rawToChar(stripNul(readBin(connection, "raw", n=2)))
                 if (any(.Dicom$longTypes == type))
                 {
                     seek(connection, where=2, origin="current")
@@ -703,7 +708,7 @@ newDicomMetadataFromFile <- function (fileName, checkFormat = TRUE, dictionary =
                     values <- c(values, as.character(value))
             }
             else
-                values <- c(values, rawToCharQuiet(readBin(connection, "raw", n=length)))
+                values <- c(values, rawToChar(stripNul(readBin(connection, "raw", n=length))))
         }
         
         close(connection)
